"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[3411],{93411:function(o,e,t){t.r(e),t.d(e,{bottomNavigationClasses:function(){return f},default:function(){return g},getBottomNavigationUtilityClass:function(){return d}});var n=t(87462),a=t(63366),r=t(72791),i=(t(57441),t(28182)),s=t(94419),l=t(66934),u=t(31402),c=t(75878),v=t(21217);function d(o){return(0,v.Z)("MuiBottomNavigation",o)}var f=(0,c.Z)("MuiBottomNavigation",["root"]),h=t(80184),p=["children","className","component","onChange","showLabels","value"],m=(0,l.ZP)("div",{name:"MuiBottomNavigation",slot:"Root",overridesResolver:function(o,e){return e.root}})((function(o){var e=o.theme;return{display:"flex",justifyContent:"center",height:56,backgroundColor:(e.vars||e).palette.background.paper}})),g=r.forwardRef((function(o,e){var t=(0,u.Z)({props:o,name:"MuiBottomNavigation"}),l=t.children,c=t.className,v=t.component,f=void 0===v?"div":v,g=t.onChange,b=t.showLabels,w=void 0!==b&&b,C=t.value,N=(0,a.Z)(t,p),Z=(0,n.Z)({},t,{component:f,showLabels:w}),k=function(o){var e=o.classes;return(0,s.Z)({root:["root"]},d,e)}(Z);return(0,h.jsx)(m,(0,n.Z)({as:f,className:(0,i.Z)(k.root,c),ref:e,ownerState:Z},N,{children:r.Children.map(l,(function(o,e){if(!r.isValidElement(o))return null;var t=void 0===o.props.value?e:o.props.value;return r.cloneElement(o,{selected:t===C,showLabel:void 0!==o.props.showLabel?o.props.showLabel:w,value:t,onChange:g})}))}))}))}}]);
//# sourceMappingURL=3411.6b37a0d9.chunk.js.map