"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2090],{25028:function(e,t,n){n.d(t,{Z:function(){return b}});var r=n(87462),i=n(63366),a=n(72791),u=(n(57441),n(98301)),l=n(43236),o=n(57137).Z,s=n(42071),c=n(40162),d=n(80184),f=["actions","autoFocus","autoFocusItem","children","className","disabledItemsFocusable","disableListWrap","onKeyDown","variant"];function v(e,t,n){return e===t?e.firstChild:t&&t.nextElementSibling?t.nextElementSibling:n?null:e.firstChild}function p(e,t,n){return e===t?n?e.firstChild:e.lastChild:t&&t.previousElementSibling?t.previousElementSibling:n?null:e.lastChild}function h(e,t){if(void 0===t)return!0;var n=e.innerText;return void 0===n&&(n=e.textContent),0!==(n=n.trim().toLowerCase()).length&&(t.repeating?n[0]===t.keys[0]:0===n.indexOf(t.keys.join("")))}function m(e,t,n,r,i,a){for(var u=!1,l=i(e,t,!!t&&n);l;){if(l===e.firstChild){if(u)return!1;u=!0}var o=!r&&(l.disabled||"true"===l.getAttribute("aria-disabled"));if(l.hasAttribute("tabindex")&&h(l,a)&&!o)return l.focus(),!0;l=i(e,l,n)}return!1}var b=a.forwardRef((function(e,t){var n=e.actions,b=e.autoFocus,g=void 0!==b&&b,y=e.autoFocusItem,w=void 0!==y&&y,C=e.children,k=e.className,x=e.disabledItemsFocusable,Z=void 0!==x&&x,E=e.disableListWrap,D=void 0!==E&&E,F=e.onKeyDown,I=e.variant,M=void 0===I?"selectedMenu":I,K=(0,i.Z)(e,f),S=a.useRef(null),L=a.useRef({keys:[],repeating:!0,previousKeyMatched:!0,lastTime:null});(0,c.Z)((function(){g&&S.current.focus()}),[g]),a.useImperativeHandle(n,(function(){return{adjustStyleForScrollbar:function(e,t){var n=!S.current.style.width;if(e.clientHeight<S.current.clientHeight&&n){var r="".concat(o((0,u.Z)(e)),"px");S.current.style["rtl"===t.direction?"paddingLeft":"paddingRight"]=r,S.current.style.width="calc(100% + ".concat(r,")")}return S.current}}}),[]);var A=(0,s.Z)(S,t),H=-1;a.Children.forEach(C,(function(e,t){a.isValidElement(e)&&(e.props.disabled||("selectedMenu"===M&&e.props.selected||-1===H)&&(H=t))}));var R=a.Children.map(C,(function(e,t){if(t===H){var n={};return w&&(n.autoFocus=!0),void 0===e.props.tabIndex&&"selectedMenu"===M&&(n.tabIndex=0),a.cloneElement(e,n)}return e}));return(0,d.jsx)(l.Z,(0,r.Z)({role:"menu",ref:A,className:k,onKeyDown:function(e){var t=S.current,n=e.key,r=(0,u.Z)(t).activeElement;if("ArrowDown"===n)e.preventDefault(),m(t,r,D,Z,v);else if("ArrowUp"===n)e.preventDefault(),m(t,r,D,Z,p);else if("Home"===n)e.preventDefault(),m(t,null,D,Z,v);else if("End"===n)e.preventDefault(),m(t,null,D,Z,p);else if(1===n.length){var i=L.current,a=n.toLowerCase(),l=performance.now();i.keys.length>0&&(l-i.lastTime>500?(i.keys=[],i.repeating=!0,i.previousKeyMatched=!0):i.repeating&&a!==i.keys[0]&&(i.repeating=!1)),i.lastTime=l,i.keys.push(a);var o=r&&!i.repeating&&h(r,i);i.previousKeyMatched&&(o||m(t,r,!1,Z,v,i))?e.preventDefault():i.previousKeyMatched=!1}F&&F(e)},tabIndex:g?0:-1},K,{children:R}))}))},92090:function(e,t,n){n.r(t),n.d(t,{default:function(){return r.Z}});var r=n(25028)},57137:function(e,t,n){function r(e){var t=e.documentElement.clientWidth;return Math.abs(window.innerWidth-t)}n.d(t,{Z:function(){return r}})}}]);
//# sourceMappingURL=2090.1344197f.chunk.js.map