"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[7511],{7511:function(t,e,n){n.r(e),n.d(e,{containerClasses:function(){return w},default:function(){return S},getContainerUtilityClass:function(){return G}});var i=n(4942),a=n(63366),r=n(87462),o=n(72791),s=n(28182),d=n(27312),u=n(21217),c=n(94419),m=n(86083),f=n(93457),x=n(85080),l=n(80184),h=["className","component","disableGutters","fixed","maxWidth","classes"],p=(0,x.Z)(),v=(0,f.Z)("div",{name:"MuiContainer",slot:"Root",overridesResolver:function(t,e){var n=t.ownerState;return[e.root,e["maxWidth".concat((0,d.Z)(String(n.maxWidth)))],n.fixed&&e.fixed,n.disableGutters&&e.disableGutters]}}),b=function(t){return(0,m.Z)({props:t,name:"MuiContainer",defaultTheme:p})},Z=function(t,e){var n=t.classes,i=t.fixed,a=t.disableGutters,r=t.maxWidth,o={root:["root",r&&"maxWidth".concat((0,d.Z)(String(r))),i&&"fixed",a&&"disableGutters"]};return(0,c.Z)(o,(function(t){return(0,u.Z)(e,t)}),n)};var W=n(14036),g=n(66934),k=n(31402),C=function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},e=t.createStyledComponent,n=void 0===e?v:e,d=t.useThemeProps,u=void 0===d?b:d,c=t.componentName,m=void 0===c?"MuiContainer":c,f=n((function(t){var e=t.theme,n=t.ownerState;return(0,r.Z)({width:"100%",marginLeft:"auto",boxSizing:"border-box",marginRight:"auto",display:"block"},!n.disableGutters&&(0,i.Z)({paddingLeft:e.spacing(2),paddingRight:e.spacing(2)},e.breakpoints.up("sm"),{paddingLeft:e.spacing(3),paddingRight:e.spacing(3)}))}),(function(t){var e=t.theme;return t.ownerState.fixed&&Object.keys(e.breakpoints.values).reduce((function(t,n){var i=n,a=e.breakpoints.values[i];return 0!==a&&(t[e.breakpoints.up(i)]={maxWidth:"".concat(a).concat(e.breakpoints.unit)}),t}),{})}),(function(t){var e=t.theme,n=t.ownerState;return(0,r.Z)({},"xs"===n.maxWidth&&(0,i.Z)({},e.breakpoints.up("xs"),{maxWidth:Math.max(e.breakpoints.values.xs,444)}),n.maxWidth&&"xs"!==n.maxWidth&&(0,i.Z)({},e.breakpoints.up(n.maxWidth),{maxWidth:"".concat(e.breakpoints.values[n.maxWidth]).concat(e.breakpoints.unit)}))})),x=o.forwardRef((function(t,e){var n=u(t),i=n.className,o=n.component,d=void 0===o?"div":o,c=n.disableGutters,x=void 0!==c&&c,p=n.fixed,v=void 0!==p&&p,b=n.maxWidth,W=void 0===b?"lg":b,g=(0,a.Z)(n,h),k=(0,r.Z)({},n,{component:d,disableGutters:x,fixed:v,maxWidth:W}),C=Z(k,m);return(0,l.jsx)(f,(0,r.Z)({as:d,ownerState:k,className:(0,s.Z)(C.root,i),ref:e},g))}));return x}({createStyledComponent:(0,g.ZP)("div",{name:"MuiContainer",slot:"Root",overridesResolver:function(t,e){var n=t.ownerState;return[e.root,e["maxWidth".concat((0,W.Z)(String(n.maxWidth)))],n.fixed&&e.fixed,n.disableGutters&&e.disableGutters]}}),useThemeProps:function(t){return(0,k.Z)({props:t,name:"MuiContainer"})}}),S=C;function G(t){return(0,u.Z)("MuiContainer",t)}var w=(0,n(75878).Z)("MuiContainer",["root","disableGutters","fixed","maxWidthXs","maxWidthSm","maxWidthMd","maxWidthLg","maxWidthXl"])},93457:function(t,e,n){var i=(0,n(44046).ZP)();e.Z=i}}]);
//# sourceMappingURL=7511.d375ca7b.chunk.js.map