"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[5067],{35067:function(n,e,r){r.r(e),r.d(e,{default:function(){return d}});var t=r(72791),o=r(87653),i=r.n(o),u=r(80184),a=t.lazy((function(){return r.e(7462).then(r.bind(r,67462))})),c=new(i().Environment);function d(n){var e,r=[],o={},i=n.context.props.formData||{};return"object"!==typeof i?r=[i]:Array.isArray(i)?r=i:o=i,e=function(n){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:[],r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},t=-1;return n.replace(/{(\d+)}/g,(function(n,r){return"undefined"!=typeof e[r]?e[r]:n})).replace(/{(\w[^}]*)}/g,(function(n,e){return"undefined"!=typeof r[e]?r[e]:n})).replace(/{(\s*)}/g,(function(n){return t++,"undefined"!=typeof e[t]?e[t]:n}))}(c.renderString(n.children.join("\n"),{data:i,props:n,window:window}),r,o),(0,u.jsx)(t.Suspense,{children:(0,u.jsx)(a,{children:e})})}c.addFilter("decimal",(function(n,e,r){var t=e?Math.pow(10,e):1;return(Math.round((n+Number.EPSILON)*t)/t).toLocaleString(r||"it")})),c.addFilter("locale",(function(n,e){return n.toLocaleString(e||"it")}))}}]);
//# sourceMappingURL=5067.174f3b50.chunk.js.map