"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[4616],{14616:function(n,e,i){i.r(e),i.d(e,{default:function(){return a}});var t=i(1413),r=i(29439),u=i(72791),f=i(48573),h=i.n(f),s=i(80184),c=u.lazy((function(){return i.e(233).then(i.t.bind(i,40233,23))}));function d(){var n=window;return{innerWidth:n.innerWidth,innerHeight:n.innerHeight}}function a(n){var e=(0,u.useState)(d()),i=(0,r.Z)(e,2),f=i[0],a=i[1];return(0,u.useEffect)((function(){window.addEventListener("resize",h()((function(){n.isOpen&&a(d())}),500))}),[n.isOpen]),(0,s.jsx)(c,(0,t.Z)({initHeight:.6*f.innerHeight,initWidth:.6*f.innerWidth},n))}}}]);
//# sourceMappingURL=4616.7890d091.chunk.js.map