"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[7231],{25502:function(e,n,t){t.d(n,{Z:function(){return a}});var u=t(87462),r=(t(72791),t(52554)),f=t(80184);function c(e){var n=e.styles,t=e.defaultTheme,u=void 0===t?{}:t,c="function"===typeof n?function(e){return n(void 0===(t=e)||null===t||0===Object.keys(t).length?u:e);var t}:n;return(0,f.jsx)(r.xB,{styles:c})}var s=t(36482);var a=function(e){return(0,f.jsx)(c,(0,u.Z)({},e,{defaultTheme:s.Z}))}},17231:function(e,n,t){t.r(n),t.d(n,{default:function(){return u.Z}});var u=t(25502)}}]);
//# sourceMappingURL=7231.0b6a2ea9.chunk.js.map