"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[9830],{79830:function(n,t,o){o.r(t),o.d(t,{cardContentClasses:function(){return C},default:function(){return Z},getCardContentUtilityClass:function(){return l}});var r=o(87462),e=o(63366),a=o(72791),s=o(28182),u=o(94419),c=o(66934),i=o(31402),d=o(75878),f=o(21217);function l(n){return(0,f.Z)("MuiCardContent",n)}var C=(0,d.Z)("MuiCardContent",["root"]),m=o(80184),p=["className","component"],v=(0,c.ZP)("div",{name:"MuiCardContent",slot:"Root",overridesResolver:function(n,t){return t.root}})((function(){return{padding:16,"&:last-child":{paddingBottom:24}}})),Z=a.forwardRef((function(n,t){var o=(0,i.Z)({props:n,name:"MuiCardContent"}),a=o.className,c=o.component,d=void 0===c?"div":c,f=(0,e.Z)(o,p),C=(0,r.Z)({},o,{component:d}),Z=function(n){var t=n.classes;return(0,u.Z)({root:["root"]},l,t)}(C);return(0,m.jsx)(v,(0,r.Z)({as:d,className:(0,s.Z)(Z.root,a),ownerState:C,ref:t},f))}))}}]);
//# sourceMappingURL=9830.6e81578a.chunk.js.map