"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[7751],{47751:function(e,h,c){var u=c(64836);Object.defineProperty(h,"__esModule",{value:!0}),h.default=void 0;var a=u(c(45649)),f=c(80184),v=(0,a.default)((0,f.jsx)("path",{d:"M18 23H4c-1.1 0-2-.9-2-2V7h2v14h14v2zM15 1H8c-1.1 0-1.99.9-1.99 2L6 17c0 1.1.89 2 1.99 2H19c1.1 0 2-.9 2-2V7l-6-6zm1.5 14h-6v-2h6v2zm0-6h-2v2h-2V9h-2V7h2V5h2v2h2v2z"}),"Difference");h.default=v}}]);
//# sourceMappingURL=7751.ccac5079.chunk.js.map