"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[8599],{58599:function(o,e,r){r.r(e),r.d(e,{default:function(){return w},getTableFooterUtilityClass:function(){return d},tableFooterClasses:function(){return m}});var t=r(87462),n=r(63366),a=r(72791),u=r(28182),s=r(94419),l=r(829),c=r(31402),i=r(66934),f=r(75878),p=r(21217);function d(o){return(0,p.Z)("MuiTableFooter",o)}var m=(0,f.Z)("MuiTableFooter",["root"]),v=r(80184),Z=["className","component"],b=(0,i.ZP)("tfoot",{name:"MuiTableFooter",slot:"Root",overridesResolver:function(o,e){return e.root}})({display:"table-footer-group"}),h={variant:"footer"},F="tfoot",w=a.forwardRef((function(o,e){var r=(0,c.Z)({props:o,name:"MuiTableFooter"}),a=r.className,i=r.component,f=void 0===i?F:i,p=(0,n.Z)(r,Z),m=(0,t.Z)({},r,{component:f}),w=function(o){var e=o.classes;return(0,s.Z)({root:["root"]},d,e)}(m);return(0,v.jsx)(l.Z.Provider,{value:h,children:(0,v.jsx)(b,(0,t.Z)({as:f,className:(0,u.Z)(w.root,a),ref:e,role:f===F?null:"rowgroup",ownerState:m},p))})}))}}]);
//# sourceMappingURL=8599.57ae5ed2.chunk.js.map