"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[3372],{23372:function(r,o,e){e.r(o),e.d(o,{accordionDetailsClasses:function(){return m},default:function(){return h},getAccordionDetailsUtilityClass:function(){return d}});var n=e(87462),t=e(63366),s=e(72791),i=e(28182),a=e(94419),c=e(66934),u=e(31402),l=e(75878),f=e(21217);function d(r){return(0,f.Z)("MuiAccordionDetails",r)}var m=(0,l.Z)("MuiAccordionDetails",["root"]),Z=e(80184),p=["className"],v=(0,c.ZP)("div",{name:"MuiAccordionDetails",slot:"Root",overridesResolver:function(r,o){return o.root}})((function(r){return{padding:r.theme.spacing(1,2,2)}})),h=s.forwardRef((function(r,o){var e=(0,u.Z)({props:r,name:"MuiAccordionDetails"}),s=e.className,c=(0,t.Z)(e,p),l=e,f=function(r){var o=r.classes;return(0,a.Z)({root:["root"]},d,o)}(l);return(0,Z.jsx)(v,(0,n.Z)({className:(0,i.Z)(f.root,s),ref:o,ownerState:l},c))}))}}]);
//# sourceMappingURL=3372.3e504db2.chunk.js.map