"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2805],{32805:function(n,e,r){r.r(e),r.d(e,{default:function(){return p}});var c=r(1413),s=r(45987),t=r(72791),u=r(58121),a=r.n(u),f=r(58323),o=r.n(f),h=r(12067),i=r(80184),l=["context","children"],d=(0,h.Z)(o());function p(n){var e=n.context,r=(n.children,(0,s.Z)(n,l));return(0,i.jsx)(t.Suspense,{children:(0,i.jsx)(d,(0,c.Z)({},Object.assign(a()(e.props.formData||{}),r)))})}}}]);
//# sourceMappingURL=2805.81c7d133.chunk.js.map