"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[1274],{11274:function(n,e,t){t.r(e),t.d(e,{default:function(){return h}});var i=t(1413),r=t(29439),l=t(72791),c=t(80184),s=l.lazy((function(){return t.e(2504).then(t.bind(t,82504))})),a=l.lazy((function(){return t.e(206).then(t.bind(t,20206))})),u=l.lazy((function(){return t.e(5201).then(t.bind(t,5201))})),d=l.lazy((function(){return t.e(7296).then(t.bind(t,37296))})),o=l.lazy((function(){return t.e(9056).then(t.bind(t,89056))}));function h(n){var e=l.useState(0),t=(0,r.Z)(e,2),h=t[0],f=t[1],p=function(n){f(n)},x=n.elements||{};return(0,c.jsxs)(l.Suspense,{children:[(0,c.jsxs)(s,{sx:{display:"flex",justifyContent:"flex-start",alignItems:"baseline",pt:1,pb:3},children:[(0,c.jsx)(o,{variant:"contained",onClick:function(){f(h-1)},disabled:0===h,children:"Back"},"back"),(0,c.jsx)(a,{activeStep:h,sx:{flexGrow:1},alternativeLabel:!0,nonLinear:!0,children:n.children.map((function(n,e){return(0,c.jsx)(u,(0,i.Z)((0,i.Z)({onClick:p.bind(null,e),style:{cursor:"pointer"}},(x[e]||{}).props),{},{children:(0,c.jsx)(d,{children:(x[(n.props||{}).index]||{}).name||((n.props||{}).schema||{}).title||(n.props||{}).name})}),e)}))},"stepper"),(0,c.jsx)(o,{variant:"contained",onClick:function(){f(h+1)},disabled:h===n.children.length-1,children:"Next"},"next")]}),(0,c.jsx)(l.Fragment,{children:n.children[h]})]})}}}]);
//# sourceMappingURL=1274.1114974e.chunk.js.map