"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[6237],{36237:function(t,e,r){r.r(e),r.d(e,{default:function(){return d},getListItemAvatarUtilityClass:function(){return v},listItemAvatarClasses:function(){return I}});var a=r(63366),n=r(87462),s=r(72791),i=r(28182),o=r(94419),l=r(66199),u=r(66934),m=r(31402),f=r(75878),c=r(21217);function v(t){return(0,c.Z)("MuiListItemAvatar",t)}var I=(0,f.Z)("MuiListItemAvatar",["root","alignItemsFlexStart"]),Z=r(80184),g=["className"],x=(0,u.ZP)("div",{name:"MuiListItemAvatar",slot:"Root",overridesResolver:function(t,e){var r=t.ownerState;return[e.root,"flex-start"===r.alignItems&&e.alignItemsFlexStart]}})((function(t){var e=t.ownerState;return(0,n.Z)({minWidth:56,flexShrink:0},"flex-start"===e.alignItems&&{marginTop:8})})),d=s.forwardRef((function(t,e){var r=(0,m.Z)({props:t,name:"MuiListItemAvatar"}),u=r.className,f=(0,a.Z)(r,g),c=s.useContext(l.Z),I=(0,n.Z)({},r,{alignItems:c.alignItems}),d=function(t){var e=t.alignItems,r=t.classes,a={root:["root","flex-start"===e&&"alignItemsFlexStart"]};return(0,o.Z)(a,v,r)}(I);return(0,Z.jsx)(x,(0,n.Z)({className:(0,i.Z)(d.root,u),ownerState:I,ref:e},f))}))}}]);
//# sourceMappingURL=6237.e4e72334.chunk.js.map