"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[503],{90503:function(e,l,u){var a=u(64836);Object.defineProperty(l,"__esModule",{value:!0}),l.default=void 0;var h=a(u(45649)),t=u(80184),d=(0,h.default)((0,t.jsx)("path",{d:"M16 9v10H8V9h8m-1.5-6h-5l-1 1H5v2h14V4h-3.5l-1-1zM18 7H6v12c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7z"}),"DeleteOutlined");l.default=d}}]);
//# sourceMappingURL=503.9577d638.chunk.js.map