"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[9871],{99871:function(n,e,t){t.r(e),t.d(e,{default:function(){return b}});var r=t(29439),a=t(1413),i=t(45987),c=t(72791),l=t(80184),u=["children","value","index"],d=c.lazy((function(){return t.e(2504).then(t.bind(t,82504))})),o=c.lazy((function(){return t.e(9212).then(t.bind(t,69212))})),s=c.lazy((function(){return t.e(3453).then(t.bind(t,13453))}));function h(n){var e=n.children,t=n.value,r=n.index,c=(0,i.Z)(n,u);return(0,l.jsx)("div",(0,a.Z)((0,a.Z)({role:"tabpanel",hidden:t!==r,id:"tabpanel-".concat(r),"aria-labelledby":"tab-".concat(r),style:{display:"contents"}},c),{},{children:t===r&&(0,l.jsxs)(d,{sx:{p:3,width:"100%"},children:[e," "]})}))}function b(n){var e=(0,c.useState)(0),t=(0,r.Z)(e,2),i=t[0],u=t[1];return(0,l.jsxs)(c.Suspense,{children:[(0,l.jsx)(s,(0,a.Z)((0,a.Z)({value:i,onChange:function(n,e){u(e)},sx:{borderRight:1,borderColor:"divider"}},n),{},{children:n.children.map((function(n,e){return(0,l.jsx)(o,(0,a.Z)({label:n.props.schema.title||"tab ".concat(e)},function(n){return{id:"tab-".concat(n),"aria-controls":"tabpanel-".concat(n)}}(e)),e)}))})),n.children.map((function(n,e){return(0,l.jsx)(h,{value:i,index:e,children:n},e)}))]})}}}]);
//# sourceMappingURL=9871.9112773c.chunk.js.map