"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[5182],{4708:function(e,t,n){n.d(t,{d1:function(){return s},dy:function(){return c}});var r=n(29439),o=n(87462),a=n(72791),i=n(31402),u=n(25502),l=n(80184),c=function(e,t){return(0,o.Z)({WebkitFontSmoothing:"antialiased",MozOsxFontSmoothing:"grayscale",boxSizing:"border-box",WebkitTextSizeAdjust:"100%"},t&&!e.vars&&{colorScheme:e.palette.mode})},s=function(e){return(0,o.Z)({color:(e.vars||e).palette.text.primary},e.typography.body1,{backgroundColor:(e.vars||e).palette.background.default,"@media print":{backgroundColor:(e.vars||e).palette.common.white}})};t.ZP=function(e){var t=(0,i.Z)({props:e,name:"MuiCssBaseline"}),n=t.children,d=t.enableColorScheme,f=void 0!==d&&d;return(0,l.jsxs)(a.Fragment,{children:[(0,l.jsx)(u.Z,{styles:function(e){return function(e){var t,n,a=arguments.length>1&&void 0!==arguments[1]&&arguments[1],i={};a&&e.colorSchemes&&Object.entries(e.colorSchemes).forEach((function(t){var n,o=(0,r.Z)(t,2),a=o[0],u=o[1];i[e.getColorSchemeSelector(a).replace(/\s*&/,"")]={colorScheme:null==(n=u.palette)?void 0:n.mode}}));var u=(0,o.Z)({html:c(e,a),"*, *::before, *::after":{boxSizing:"inherit"},"strong, b":{fontWeight:e.typography.fontWeightBold},body:(0,o.Z)({margin:0},s(e),{"&::backdrop":{backgroundColor:(e.vars||e).palette.background.default}})},i),l=null==(t=e.components)||null==(n=t.MuiCssBaseline)?void 0:n.styleOverrides;return l&&(u=[u,l]),u}(e,f)}}),n]})}},15182:function(e,t,n){n.r(t),n.d(t,{default:function(){return r.ZP}});var r=n(4708)},25502:function(e,t,n){n.d(t,{Z:function(){return l}});var r=n(87462),o=(n(72791),n(52554)),a=n(80184);function i(e){var t=e.styles,n=e.defaultTheme,r=void 0===n?{}:n,i="function"===typeof t?function(e){return t(void 0===(n=e)||null===n||0===Object.keys(n).length?r:e);var n}:t;return(0,a.jsx)(o.xB,{styles:i})}var u=n(36482);var l=function(e){return(0,a.jsx)(i,(0,r.Z)({},e,{defaultTheme:u.Z}))}}}]);
//# sourceMappingURL=5182.eb3386b6.chunk.js.map