"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[588],{51157:function(t,n,r){var o,e,a=r(4942),i=r(63366),l=r(87462),u=r(72791),c=r(28182),s=r(94419),d=r(7883),f=r(11883),Z=r(2863),v=r(13967),b=r(31402),h=r(66934),S=r(67037),m=r(80184),p=["className","direction","orientation","disabled"],w=(0,h.ZP)(Z.Z,{name:"MuiTabScrollButton",slot:"Root",overridesResolver:function(t,n){var r=t.ownerState;return[n.root,r.orientation&&n[r.orientation]]}})((function(t){var n=t.ownerState;return(0,l.Z)((0,a.Z)({width:40,flexShrink:0,opacity:.8},"&.".concat(S.Z.disabled),{opacity:0}),"vertical"===n.orientation&&{width:"100%",height:40,"& svg":{transform:"rotate(".concat(n.isRtl?-90:90,"deg)")}})})),x=u.forwardRef((function(t,n){var r=(0,b.Z)({props:t,name:"MuiTabScrollButton"}),a=r.className,u=r.direction,Z=(0,i.Z)(r,p),h="rtl"===(0,v.Z)().direction,x=(0,l.Z)({isRtl:h},r),C=function(t){var n=t.classes,r={root:["root",t.orientation,t.disabled&&"disabled"]};return(0,s.Z)(r,S.C,n)}(x);return(0,m.jsx)(w,(0,l.Z)({component:"div",className:(0,c.Z)(C.root,a),ref:n,role:null,ownerState:x,tabIndex:null},Z,{children:"left"===u?o||(o=(0,m.jsx)(d.Z,{fontSize:"small"})):e||(e=(0,m.jsx)(f.Z,{fontSize:"small"}))}))}));n.Z=x},70588:function(t,n,r){r.r(n),r.d(n,{default:function(){return o.Z},getTabScrollButtonUtilityClass:function(){return e.C},tabScrollButtonClasses:function(){return e.Z}});var o=r(51157),e=r(67037)},67037:function(t,n,r){r.d(n,{C:function(){return a}});var o=r(75878),e=r(21217);function a(t){return(0,e.Z)("MuiTabScrollButton",t)}var i=(0,o.Z)("MuiTabScrollButton",["root","vertical","horizontal","disabled"]);n.Z=i},7883:function(t,n,r){r(72791);var o=r(74223),e=r(80184);n.Z=(0,o.Z)((0,e.jsx)("path",{d:"M15.41 16.09l-4.58-4.59 4.58-4.59L14 5.5l-6 6 6 6z"}),"KeyboardArrowLeft")},11883:function(t,n,r){r(72791);var o=r(74223),e=r(80184);n.Z=(0,o.Z)((0,e.jsx)("path",{d:"M8.59 16.34l4.58-4.59-4.58-4.59L10 5.75l6 6-6 6z"}),"KeyboardArrowRight")},13967:function(t,n,r){r.d(n,{Z:function(){return a}});r(72791);var o=r(30418),e=r(36482);function a(){return(0,o.Z)(e.Z)}}}]);
//# sourceMappingURL=588.cdabc93a.chunk.js.map