"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[1985],{11985:function(e,o,r){r.r(o),r.d(o,{default:function(){return z},getIconUtilityClass:function(){return p},iconClasses:function(){return d}});var n=r(87462),t=r(63366),a=r(72791),i=r(28182),c=r(94419),s=r(66934),l=r(31402),m=r(14036),u=r(75878),f=r(21217);function p(e){return(0,f.Z)("MuiIcon",e)}var d=(0,u.Z)("MuiIcon",["root","colorPrimary","colorSecondary","colorAction","colorError","colorDisabled","fontSizeInherit","fontSizeSmall","fontSizeMedium","fontSizeLarge"]),v=r(80184),h=["baseClassName","className","color","component","fontSize"],S=(0,s.ZP)("span",{name:"MuiIcon",slot:"Root",overridesResolver:function(e,o){var r=e.ownerState;return[o.root,"inherit"!==r.color&&o["color".concat((0,m.Z)(r.color))],o["fontSize".concat((0,m.Z)(r.fontSize))]]}})((function(e){var o=e.theme,r=e.ownerState;return{userSelect:"none",width:"1em",height:"1em",overflow:"hidden",display:"inline-block",textAlign:"center",flexShrink:0,fontSize:{inherit:"inherit",small:o.typography.pxToRem(20),medium:o.typography.pxToRem(24),large:o.typography.pxToRem(36)}[r.fontSize],color:{primary:(o.vars||o).palette.primary.main,secondary:(o.vars||o).palette.secondary.main,info:(o.vars||o).palette.info.main,success:(o.vars||o).palette.success.main,warning:(o.vars||o).palette.warning.main,action:(o.vars||o).palette.action.active,error:(o.vars||o).palette.error.main,disabled:(o.vars||o).palette.action.disabled,inherit:void 0}[r.color]}})),y=a.forwardRef((function(e,o){var r=(0,l.Z)({props:e,name:"MuiIcon"}),a=r.baseClassName,s=void 0===a?"material-icons":a,u=r.className,f=r.color,d=void 0===f?"inherit":f,y=r.component,z=void 0===y?"span":y,Z=r.fontSize,g=void 0===Z?"medium":Z,w=(0,t.Z)(r,h),b=(0,n.Z)({},r,{baseClassName:s,color:d,component:z,fontSize:g}),C=function(e){var o=e.color,r=e.fontSize,n=e.classes,t={root:["root","inherit"!==o&&"color".concat((0,m.Z)(o)),"fontSize".concat((0,m.Z)(r))]};return(0,c.Z)(t,p,n)}(b);return(0,v.jsx)(S,(0,n.Z)({as:z,className:(0,i.Z)(s,"notranslate",C.root,u),ownerState:b,"aria-hidden":!0,ref:o},w))}));y.muiName="Icon";var z=y}}]);
//# sourceMappingURL=1985.f31e0bb9.chunk.js.map