"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[7368],{77368:function(o,t,e){e.r(t),e.d(t,{default:function(){return w},dialogContentClasses:function(){return p},getDialogContentUtilityClass:function(){return f}});var r=e(4942),i=e(63366),n=e(87462),a=e(72791),d=e(28182),s=e(94419),u=e(66934),l=e(31402),c=e(75878),v=e(21217);function f(o){return(0,v.Z)("MuiDialogContent",o)}var p=(0,c.Z)("MuiDialogContent",["root","dividers"]),Z=e(17673),g=e(80184),C=["className","dividers"],m=(0,u.ZP)("div",{name:"MuiDialogContent",slot:"Root",overridesResolver:function(o,t){var e=o.ownerState;return[t.root,e.dividers&&t.dividers]}})((function(o){var t=o.theme,e=o.ownerState;return(0,n.Z)({flex:"1 1 auto",WebkitOverflowScrolling:"touch",overflowY:"auto",padding:"20px 24px"},e.dividers?{padding:"16px 24px",borderTop:"1px solid ".concat((t.vars||t).palette.divider),borderBottom:"1px solid ".concat((t.vars||t).palette.divider)}:(0,r.Z)({},".".concat(Z.Z.root," + &"),{paddingTop:0}))})),w=a.forwardRef((function(o,t){var e=(0,l.Z)({props:o,name:"MuiDialogContent"}),r=e.className,a=e.dividers,u=void 0!==a&&a,c=(0,i.Z)(e,C),v=(0,n.Z)({},e,{dividers:u}),p=function(o){var t=o.classes,e={root:["root",o.dividers&&"dividers"]};return(0,s.Z)(e,f,t)}(v);return(0,g.jsx)(m,(0,n.Z)({className:(0,d.Z)(p.root,r),ownerState:v,ref:t},c))}))},17673:function(o,t,e){e.d(t,{a:function(){return n}});var r=e(75878),i=e(21217);function n(o){return(0,i.Z)("MuiDialogTitle",o)}var a=(0,r.Z)("MuiDialogTitle",["root"]);t.Z=a}}]);
//# sourceMappingURL=7368.2a26b723.chunk.js.map