"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[1073],{60220:function(r,e,t){t.d(e,{Z:function(){return b}});var a=t(29439),o=t(63366),n=t(87462),i=t(72791),s=t(28182),c=t(94419),l=t(66934),u=t(31402),f=t(74223),d=t(80184),v=(0,f.Z)((0,d.jsx)("path",{d:"M12 12c2.21 0 4-1.79 4-4s-1.79-4-4-4-4 1.79-4 4 1.79 4 4 4zm0 2c-2.67 0-8 1.34-8 4v2h16v-2c0-2.66-5.33-4-8-4z"}),"Person"),m=t(72800),g=["alt","children","className","component","imgProps","sizes","src","srcSet","variant"],h=(0,l.ZP)("div",{name:"MuiAvatar",slot:"Root",overridesResolver:function(r,e){var t=r.ownerState;return[e.root,e[t.variant],t.colorDefault&&e.colorDefault]}})((function(r){var e=r.theme,t=r.ownerState;return(0,n.Z)({position:"relative",display:"flex",alignItems:"center",justifyContent:"center",flexShrink:0,width:40,height:40,fontFamily:e.typography.fontFamily,fontSize:e.typography.pxToRem(20),lineHeight:1,borderRadius:"50%",overflow:"hidden",userSelect:"none"},"rounded"===t.variant&&{borderRadius:(e.vars||e).shape.borderRadius},"square"===t.variant&&{borderRadius:0},t.colorDefault&&(0,n.Z)({color:(e.vars||e).palette.background.default},e.vars?{backgroundColor:e.vars.palette.Avatar.defaultBg}:{backgroundColor:"light"===e.palette.mode?e.palette.grey[400]:e.palette.grey[600]}))})),p=(0,l.ZP)("img",{name:"MuiAvatar",slot:"Img",overridesResolver:function(r,e){return e.img}})({width:"100%",height:"100%",textAlign:"center",objectFit:"cover",color:"transparent",textIndent:1e4}),Z=(0,l.ZP)(v,{name:"MuiAvatar",slot:"Fallback",overridesResolver:function(r,e){return e.fallback}})({width:"75%",height:"75%"});var b=i.forwardRef((function(r,e){var t=(0,u.Z)({props:r,name:"MuiAvatar"}),l=t.alt,f=t.children,v=t.className,b=t.component,k=void 0===b?"div":b,y=t.imgProps,S=t.sizes,w=t.src,R=t.srcSet,x=t.variant,A=void 0===x?"circular":x,P=(0,o.Z)(t,g),C=null,D=function(r){var e=r.crossOrigin,t=r.referrerPolicy,o=r.src,n=r.srcSet,s=i.useState(!1),c=(0,a.Z)(s,2),l=c[0],u=c[1];return i.useEffect((function(){if(o||n){u(!1);var r=!0,a=new Image;return a.onload=function(){r&&u("loaded")},a.onerror=function(){r&&u("error")},a.crossOrigin=e,a.referrerPolicy=t,a.src=o,n&&(a.srcset=n),function(){r=!1}}}),[e,t,o,n]),l}((0,n.Z)({},y,{src:w,srcSet:R})),M=w||R,j=M&&"error"!==D,z=(0,n.Z)({},t,{colorDefault:!j,component:k,variant:A}),N=function(r){var e=r.classes,t={root:["root",r.variant,r.colorDefault&&"colorDefault"],img:["img"],fallback:["fallback"]};return(0,c.Z)(t,m.$,e)}(z);return C=j?(0,d.jsx)(p,(0,n.Z)({alt:l,src:w,srcSet:R,sizes:S,ownerState:z,className:N.img},y)):null!=f?f:M&&l?l[0]:(0,d.jsx)(Z,{className:N.fallback}),(0,d.jsx)(h,(0,n.Z)({as:k,ownerState:z,className:(0,s.Z)(N.root,v),ref:e},P,{children:C}))}))},72800:function(r,e,t){t.d(e,{$:function(){return n}});var a=t(75878),o=t(21217);function n(r){return(0,o.Z)("MuiAvatar",r)}var i=(0,a.Z)("MuiAvatar",["root","colorDefault","circular","rounded","square","img","fallback"]);e.Z=i},81073:function(r,e,t){t.r(e),t.d(e,{avatarClasses:function(){return o.Z},default:function(){return a.Z},getAvatarUtilityClass:function(){return o.$}});var a=t(60220),o=t(72800)}}]);
//# sourceMappingURL=1073.db6809a3.chunk.js.map