"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[7499],{87499:function(t,o,i){i.r(o),i.d(o,{cardActionAreaClasses:function(){return g},default:function(){return b},getCardActionAreaUtilityClass:function(){return d}});var e=i(4942),r=i(87462),a=i(63366),n=i(72791),s=i(28182),c=i(94419),u=i(31402),l=i(66934),f=i(75878),h=i(21217);function d(t){return(0,h.Z)("MuiCardActionArea",t)}var g=(0,f.Z)("MuiCardActionArea",["root","focusVisible","focusHighlight"]),p=i(2863),v=i(80184),m=["children","className","focusVisibleClassName"],A=(0,l.ZP)(p.Z,{name:"MuiCardActionArea",slot:"Root",overridesResolver:function(t,o){return o.root}})((function(t){var o,i=t.theme;return o={display:"block",textAlign:"inherit",width:"100%"},(0,e.Z)(o,"&:hover .".concat(g.focusHighlight),{opacity:(i.vars||i).palette.action.hoverOpacity,"@media (hover: none)":{opacity:0}}),(0,e.Z)(o,"&.".concat(g.focusVisible," .").concat(g.focusHighlight),{opacity:(i.vars||i).palette.action.focusOpacity}),o})),C=(0,l.ZP)("span",{name:"MuiCardActionArea",slot:"FocusHighlight",overridesResolver:function(t,o){return o.focusHighlight}})((function(t){var o=t.theme;return{overflow:"hidden",pointerEvents:"none",position:"absolute",top:0,right:0,bottom:0,left:0,borderRadius:"inherit",opacity:0,backgroundColor:"currentcolor",transition:o.transitions.create("opacity",{duration:o.transitions.duration.short})}})),b=n.forwardRef((function(t,o){var i=(0,u.Z)({props:t,name:"MuiCardActionArea"}),e=i.children,n=i.className,l=i.focusVisibleClassName,f=(0,a.Z)(i,m),h=i,g=function(t){var o=t.classes;return(0,c.Z)({root:["root"],focusHighlight:["focusHighlight"]},d,o)}(h);return(0,v.jsxs)(A,(0,r.Z)({className:(0,s.Z)(g.root,n),focusVisibleClassName:(0,s.Z)(l,g.focusVisible),ref:o,ownerState:h},f,{children:[e,(0,v.jsx)(C,{className:g.focusHighlight,ownerState:h})]}))}))}}]);
//# sourceMappingURL=7499.82456483.chunk.js.map