"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[7762],{3952:function(n,e,u){var c=u(29439),f=u(72791),r=u(75721),t=u(80184);e.Z=function(n){var e=n.children,u=n.defer,a=void 0!==u&&u,i=n.fallback,l=void 0===i?null:i,o=f.useState(!1),s=(0,c.Z)(o,2),d=s[0],h=s[1];return(0,r.Z)((function(){a||h(!0)}),[a]),f.useEffect((function(){a&&h(!0)}),[a]),(0,t.jsx)(f.Fragment,{children:d?e:l})}},57762:function(n,e,u){u.r(e),u.d(e,{default:function(){return c.Z}});var c=u(3952)}}]);
//# sourceMappingURL=7762.744763b8.chunk.js.map