"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[2630],{27938:function(e,a,t){t.d(a,{Z:function(){return Z}});var n=t(63366),o=t(87462),r=t(72791),i=t(28182),v=t(94419),l=t(12065),u=t(66934),s=function(e){return((e<1?5.11916*Math.pow(e,2):4.5*Math.log(e+1)+2)/100).toFixed(2)},c=t(31402),d=t(38550),f=t(80184),p=["className","component","elevation","square","variant"],m=(0,u.ZP)("div",{name:"MuiPaper",slot:"Root",overridesResolver:function(e,a){var t=e.ownerState;return[a.root,a[t.variant],!t.square&&a.rounded,"elevation"===t.variant&&a["elevation".concat(t.elevation)]]}})((function(e){var a,t=e.theme,n=e.ownerState;return(0,o.Z)({backgroundColor:(t.vars||t).palette.background.paper,color:(t.vars||t).palette.text.primary,transition:t.transitions.create("box-shadow")},!n.square&&{borderRadius:t.shape.borderRadius},"outlined"===n.variant&&{border:"1px solid ".concat((t.vars||t).palette.divider)},"elevation"===n.variant&&(0,o.Z)({boxShadow:(t.vars||t).shadows[n.elevation]},!t.vars&&"dark"===t.palette.mode&&{backgroundImage:"linear-gradient(".concat((0,l.Fq)("#fff",s(n.elevation)),", ").concat((0,l.Fq)("#fff",s(n.elevation)),")")},t.vars&&{backgroundImage:null==(a=t.vars.overlays)?void 0:a[n.elevation]}))})),Z=r.forwardRef((function(e,a){var t=(0,c.Z)({props:e,name:"MuiPaper"}),r=t.className,l=t.component,u=void 0===l?"div":l,s=t.elevation,Z=void 0===s?1:s,h=t.square,b=void 0!==h&&h,w=t.variant,g=void 0===w?"elevation":w,k=(0,n.Z)(t,p),q=(0,o.Z)({},t,{component:u,elevation:Z,square:b,variant:g}),x=function(e){var a=e.square,t=e.elevation,n=e.variant,o=e.classes,r={root:["root",n,!a&&"rounded","elevation"===n&&"elevation".concat(t)]};return(0,v.Z)(r,d.J,o)}(q);return(0,f.jsx)(m,(0,o.Z)({as:u,ownerState:q,className:(0,i.Z)(x.root,r),ref:a},k))}))},42630:function(e,a,t){t.r(a),t.d(a,{default:function(){return n.Z},getPaperUtilityClass:function(){return o.J},paperClasses:function(){return o.Z}});var n=t(27938),o=t(38550)},38550:function(e,a,t){t.d(a,{J:function(){return r}});var n=t(75878),o=t(21217);function r(e){return(0,o.Z)("MuiPaper",e)}var i=(0,n.Z)("MuiPaper",["root","rounded","outlined","elevation","elevation0","elevation1","elevation2","elevation3","elevation4","elevation5","elevation6","elevation7","elevation8","elevation9","elevation10","elevation11","elevation12","elevation13","elevation14","elevation15","elevation16","elevation17","elevation18","elevation19","elevation20","elevation21","elevation22","elevation23","elevation24"]);a.Z=i}}]);
//# sourceMappingURL=2630.6c0e70f4.chunk.js.map