"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[4298],{60627:function(n,t,e){var i=e(87462),o=e(63366),r=e(72791),a=e(26752),s=e(13967),d=e(4999),c=e(42071),u=e(80184),l=["addEndListener","appear","children","easing","in","onEnter","onEntered","onEntering","onExit","onExited","onExiting","style","timeout","TransitionComponent"],f={entering:{opacity:1},entered:{opacity:1}},E=r.forwardRef((function(n,t){var e=(0,s.Z)(),E={enter:e.transitions.duration.enteringScreen,exit:e.transitions.duration.leavingScreen},p=n.addEndListener,y=n.appear,g=void 0===y||y,v=n.children,x=n.easing,m=n.in,h=n.onEnter,Z=n.onEntered,k=n.onEntering,C=n.onExit,b=n.onExited,w=n.onExiting,T=n.style,L=n.timeout,R=void 0===L?E:L,S=n.TransitionComponent,_=void 0===S?a.ZP:S,j=(0,o.Z)(n,l),P=r.useRef(null),q=(0,c.Z)(P,v.ref,t),z=function(n){return function(t){if(n){var e=P.current;void 0===t?n(e):n(e,t)}}},A=z(k),B=z((function(n,t){(0,d.n)(n);var i=(0,d.C)({style:T,timeout:R,easing:x},{mode:"enter"});n.style.webkitTransition=e.transitions.create("opacity",i),n.style.transition=e.transitions.create("opacity",i),h&&h(n,t)})),D=z(Z),F=z(w),G=z((function(n){var t=(0,d.C)({style:T,timeout:R,easing:x},{mode:"exit"});n.style.webkitTransition=e.transitions.create("opacity",t),n.style.transition=e.transitions.create("opacity",t),C&&C(n)})),H=z(b);return(0,u.jsx)(_,(0,i.Z)({appear:g,in:m,nodeRef:P,onEnter:B,onEntered:D,onEntering:A,onExit:G,onExited:H,onExiting:F,addEndListener:function(n){p&&p(P.current,n)},timeout:R},j,{children:function(n,t){return r.cloneElement(v,(0,i.Z)({style:(0,i.Z)({opacity:0,visibility:"exited"!==n||m?void 0:"hidden"},f[n],T,v.props.style),ref:q},t))}}))}));t.Z=E},31234:function(n,t,e){e.r(t),e.d(t,{default:function(){return i.Z}});var i=e(60627)}}]);
//# sourceMappingURL=4298.3ba9461e.chunk.js.map