"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[4693],{74693:function(n,u,e){e.r(u),e.d(u,{default:function(){return s.Z},getSvgIconUtilityClass:function(){return t.h},svgIconClasses:function(){return t.Z}});var s=e(40558),t=e(8232)}}]);