.flexible-modal{background:transparent!important;border:none!important;position:absolute!important;z-index:10000000000!important}.flexible-modal-mask{background:rgba(55,55,55,.6)!important;bottom:0!important;display:none!important;height:100%!important;left:0!important;position:fixed!important;right:0!important;top:0!important}.flexible-modal-resizer{border-bottom:2px solid #333!important;border-right:2px solid #333!important;bottom:0!important;cursor:se-resize!important;margin:5px!important;position:absolute!important;right:0!important}.flexible-modal-drag-area{background:transparent none repeat 0 0/auto auto padding-box border-box scroll!important;background:initial!important;cursor:move!important;height:64px!important;left:0!important;position:absolute;right:64px!important;top:0!important;width:auto!important}.flexible-modal-drag-area-bottom,.flexible-modal-drag-area-left,.flexible-modal-drag-area-right,.flexible-modal-drag-area-top{display:none!important}
/*# sourceMappingURL=4616.52994b53.chunk.css.map*/