"use strict";(self.webpackChunkschedula_form=self.webpackChunkschedula_form||[]).push([[706],{70706:function(t,e,n){n.r(e),n.d(e,{default:function(){return s.Z},getListItemSecondaryActionClassesUtilityClass:function(){return u.A},listItemSecondaryActionClasses:function(){return u.Z}});var s=n(47055),u=n(96111)}}]);